# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKLevelSetsPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkSegmentationLevelSetFunctionPython
else:
    import _itkSegmentationLevelSetFunctionPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkLevelSetFunctionPython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkPointPython
import itk.vnl_vector_refPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrixPython
import itk.itkFixedArrayPython
import itk.itkVectorPython
import itk.itkCovariantVectorPython
import itk.vnl_matrix_fixedPython
import itk.itkFiniteDifferenceFunctionPython
import itk.itkSizePython
import itk.itkImagePython
import itk.itkRGBAPixelPython
import itk.itkRGBPixelPython
import itk.itkOffsetPython
import itk.itkImageRegionPython
import itk.itkIndexPython
import itk.itkSymmetricSecondRankTensorPython
class itkSegmentationLevelSetFunctionIF2IF2(itk.itkLevelSetFunctionPython.itkLevelSetFunctionIF2):
    r"""Proxy of C++ itkSegmentationLevelSetFunctionIF2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetFeatureImage(self):
        r"""GetFeatureImage(self) -> itkImageF2"""
        return _itkSegmentationLevelSetFunctionPython.itkSegmentationLevelSetFunctionIF2IF2_GetFeatureImage(self)

    def SetFeatureImage(self, f):
        r"""
        SetFeatureImage(self, f)

        Parameters
        ----------
        f: itkImageF2 const *

        """
        return _itkSegmentationLevelSetFunctionPython.itkSegmentationLevelSetFunctionIF2IF2_SetFeatureImage(self, f)

    def GetSpeedImage(self):
        r"""GetSpeedImage(self) -> itkImageF2"""
        return _itkSegmentationLevelSetFunctionPython.itkSegmentationLevelSetFunctionIF2IF2_GetSpeedImage(self)

    def SetSpeedImage(self, s):
        r"""
        SetSpeedImage(self, s)

        Parameters
        ----------
        s: itkImageF2 *

        """
        return _itkSegmentationLevelSetFunctionPython.itkSegmentationLevelSetFunctionIF2IF2_SetSpeedImage(self, s)

    def GetAdvectionImage(self):
        r"""GetAdvectionImage(self) -> itkImageFAF22"""
        return _itkSegmentationLevelSetFunctionPython.itkSegmentationLevelSetFunctionIF2IF2_GetAdvectionImage(self)

    def SetAdvectionImage(self, s):
        r"""
        SetAdvectionImage(self, s)

        Parameters
        ----------
        s: itkImageFAF22 *

        """
        return _itkSegmentationLevelSetFunctionPython.itkSegmentationLevelSetFunctionIF2IF2_SetAdvectionImage(self, s)

    def CalculateSpeedImage(self):
        r"""CalculateSpeedImage(self)"""
        return _itkSegmentationLevelSetFunctionPython.itkSegmentationLevelSetFunctionIF2IF2_CalculateSpeedImage(self)

    def CalculateAdvectionImage(self):
        r"""CalculateAdvectionImage(self)"""
        return _itkSegmentationLevelSetFunctionPython.itkSegmentationLevelSetFunctionIF2IF2_CalculateAdvectionImage(self)

    def AllocateSpeedImage(self):
        r"""AllocateSpeedImage(self)"""
        return _itkSegmentationLevelSetFunctionPython.itkSegmentationLevelSetFunctionIF2IF2_AllocateSpeedImage(self)

    def AllocateAdvectionImage(self):
        r"""AllocateAdvectionImage(self)"""
        return _itkSegmentationLevelSetFunctionPython.itkSegmentationLevelSetFunctionIF2IF2_AllocateAdvectionImage(self)

    def ReverseExpansionDirection(self):
        r"""ReverseExpansionDirection(self)"""
        return _itkSegmentationLevelSetFunctionPython.itkSegmentationLevelSetFunctionIF2IF2_ReverseExpansionDirection(self)
    __swig_destroy__ = _itkSegmentationLevelSetFunctionPython.delete_itkSegmentationLevelSetFunctionIF2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkSegmentationLevelSetFunctionIF2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkSegmentationLevelSetFunctionPython.itkSegmentationLevelSetFunctionIF2IF2_cast(obj)

# Register itkSegmentationLevelSetFunctionIF2IF2 in _itkSegmentationLevelSetFunctionPython:
_itkSegmentationLevelSetFunctionPython.itkSegmentationLevelSetFunctionIF2IF2_swigregister(itkSegmentationLevelSetFunctionIF2IF2)
class itkSegmentationLevelSetFunctionIF3IF3(itk.itkLevelSetFunctionPython.itkLevelSetFunctionIF3):
    r"""Proxy of C++ itkSegmentationLevelSetFunctionIF3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetFeatureImage(self):
        r"""GetFeatureImage(self) -> itkImageF3"""
        return _itkSegmentationLevelSetFunctionPython.itkSegmentationLevelSetFunctionIF3IF3_GetFeatureImage(self)

    def SetFeatureImage(self, f):
        r"""
        SetFeatureImage(self, f)

        Parameters
        ----------
        f: itkImageF3 const *

        """
        return _itkSegmentationLevelSetFunctionPython.itkSegmentationLevelSetFunctionIF3IF3_SetFeatureImage(self, f)

    def GetSpeedImage(self):
        r"""GetSpeedImage(self) -> itkImageF3"""
        return _itkSegmentationLevelSetFunctionPython.itkSegmentationLevelSetFunctionIF3IF3_GetSpeedImage(self)

    def SetSpeedImage(self, s):
        r"""
        SetSpeedImage(self, s)

        Parameters
        ----------
        s: itkImageF3 *

        """
        return _itkSegmentationLevelSetFunctionPython.itkSegmentationLevelSetFunctionIF3IF3_SetSpeedImage(self, s)

    def GetAdvectionImage(self):
        r"""GetAdvectionImage(self) -> itkImageFAF33"""
        return _itkSegmentationLevelSetFunctionPython.itkSegmentationLevelSetFunctionIF3IF3_GetAdvectionImage(self)

    def SetAdvectionImage(self, s):
        r"""
        SetAdvectionImage(self, s)

        Parameters
        ----------
        s: itkImageFAF33 *

        """
        return _itkSegmentationLevelSetFunctionPython.itkSegmentationLevelSetFunctionIF3IF3_SetAdvectionImage(self, s)

    def CalculateSpeedImage(self):
        r"""CalculateSpeedImage(self)"""
        return _itkSegmentationLevelSetFunctionPython.itkSegmentationLevelSetFunctionIF3IF3_CalculateSpeedImage(self)

    def CalculateAdvectionImage(self):
        r"""CalculateAdvectionImage(self)"""
        return _itkSegmentationLevelSetFunctionPython.itkSegmentationLevelSetFunctionIF3IF3_CalculateAdvectionImage(self)

    def AllocateSpeedImage(self):
        r"""AllocateSpeedImage(self)"""
        return _itkSegmentationLevelSetFunctionPython.itkSegmentationLevelSetFunctionIF3IF3_AllocateSpeedImage(self)

    def AllocateAdvectionImage(self):
        r"""AllocateAdvectionImage(self)"""
        return _itkSegmentationLevelSetFunctionPython.itkSegmentationLevelSetFunctionIF3IF3_AllocateAdvectionImage(self)

    def ReverseExpansionDirection(self):
        r"""ReverseExpansionDirection(self)"""
        return _itkSegmentationLevelSetFunctionPython.itkSegmentationLevelSetFunctionIF3IF3_ReverseExpansionDirection(self)
    __swig_destroy__ = _itkSegmentationLevelSetFunctionPython.delete_itkSegmentationLevelSetFunctionIF3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkSegmentationLevelSetFunctionIF3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkSegmentationLevelSetFunctionPython.itkSegmentationLevelSetFunctionIF3IF3_cast(obj)

# Register itkSegmentationLevelSetFunctionIF3IF3 in _itkSegmentationLevelSetFunctionPython:
_itkSegmentationLevelSetFunctionPython.itkSegmentationLevelSetFunctionIF3IF3_swigregister(itkSegmentationLevelSetFunctionIF3IF3)

